# euros

Simple script python destiné à convertir des chiffres en lettres, pour désigner un montant en euros en français littéral respectant les règles orthographiques.

Installation :

`python3 -m pip install euros`

Exemples d'utilisation :

`>>> from euros import fr`

`>>> fr.conv(10) # Output : "dix euros"`

`>>> fr.conv(120.99) # Output : "cent vint euros et quatre-vingt-dix-neuf centimes"`

